"""
heli.py - Arian Mollik Wasi
MIT License

A simple script to print a helicopter animation to the terminal.
The heli_animation.txt file should be in the same folder as this file or else the code won't work

Usage
=====
To run normally use
    python heli.py
To specify a custom frame duration use
    python heli.py n
Where n is the duration such as 0.5:
    python heli.py 0.5
"""
import os
import sys
import itertools
import time


def clear():
    """Clear the terminal"""
    # `cls` is a Windows command and `clear` is a Unix command to clear the terminal
    os.system("cls" if os.name == "nt" else "clear")


with open("heli_animation.txt", encoding="utf-8") as f:
    # `itertools.cycle` creates a infinite iterable so the animation never stops
    # `i.strip("\n")` is there to remove trailing newlines
    # `filter(None, sequence)` removes all falsey elements such as empty strings
    # `f.read().split(...)` gets all the parts of the helicopter animation as a list
    helicopter_phases = itertools.cycle(
        [i.strip("\n") for i in filter(None, f.read().split("===================================="))]
    )

def print_heli():
    try:
        for heli_frame in helicopter_phases:
            print(heli_frame)
            # Since the value of the end parameter for `print()` is by default a newline
            # I can use a empty print without arguments to print only a newline
            print()
            # I add a `time.sleep` to delay the frames or else it will be too fast
            # I check if there is a custom delay passed and if not, it uses 0.1
            time.sleep(float(sys.argv[1]) if sys.argv[1:] else 0.1)
            # I clear the terminal after the run
            clear()
    except KeyboardInterrupt:
        print("Stopped!")

if __name__ == "__main__":
    print_heli()
    # One last clear just to be sure
    clear()



from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / 'README.md').read_text(encoding='utf-8')

setup(
    name='helikopter',
    version='1.0.1',
    description='A simple script to print a helicopter to the terminal',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/wasi-master/helicopter-helicopter',
    author='Wasi Master',
    author_email='arianmollik323@gmail.com',

    # For a list of valid classifiers, see https://pypi.org/classifiers/
    classifiers=[  # Optional
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Games/Entertainment',
        'Topic :: Terminals',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3 :: Only',
    ],
    keywords='helicopter, meme, helikopter, helicopter-helicopter, helikopter-helikopter',
    packages=['helikopter'],
    python_requires='>=3.0, <4',
    project_urls={
        'Bug Reports': 'https://github.com/wasi-master/helicopter-helicopter/issues',
        'Say Thanks!': 'https://saythanks.io/to/wasi-master',
        'Source': 'https://github.com/wasi-master/helicopter-helicopter',
    },
    package_data={
        'helikopter': ['heli_animation.txt'],
    },
)
